summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/assocgenpage.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /umbrello/umbrello/dialogs/assocgenpage.h
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/dialogs/assocgenpage.h')
-rw-r--r--umbrello/umbrello/dialogs/assocgenpage.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/umbrello/umbrello/dialogs/assocgenpage.h b/umbrello/umbrello/dialogs/assocgenpage.h
index 4cd34421..06c32c05 100644
--- a/umbrello/umbrello/dialogs/assocgenpage.h
+++ b/umbrello/umbrello/dialogs/assocgenpage.h
@@ -42,16 +42,17 @@ class KComboBox;
*/
class AssocGenPage : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Sets up the AssocGenPage.
*
* @param d The UMLDoc which controls controls object creation.
* @param parent The parent to the AssocGenPage.
* @param a The AssociationWidget to display the properties of.
*/
- AssocGenPage(UMLDoc *d, TQWidget *parent, AssociationWidget *a);
+ AssocGenPage(UMLDoc *d, TQWidget *tqparent, AssociationWidget *a);
/**
* Standard deconstructor.
@@ -42,16 +42,17 @@ class KComboBox;
*
* @param d The UMLDoc which controls controls object creation.
- * @param parent The parent to the AssocGenPage.
+ * @param tqparent The tqparent to the AssocGenPage.
* @param a The AssociationWidget to display the properties of.
*/